decode_cancel_open_orders

Function decode_cancel_open_orders 

pub fn decode_cancel_open_orders(
    buf: &[u8],
) -> Result<Vec<BinanceCancelOrderResponse>, SbeDecodeError>
Decode cancel open orders response.

Each item in the response group contains an embedded cancel_order_response SBE message.

Errors

Returns error if buffer is too short, schema mismatch, or decode error.